@@ -15,6 +15,7 @@ RUN_INSTALLER=${RUN_INSTALLER:-1}
 DO_MSI=${DO_MSI:-0}
 DO_SIGN=${DO_SIGN:-1}
 DO_TESTS=${DO_TESTS:-0}
+DO_SBOM=${DO_SBOM:1}
 
 # these are only enabled for "full" builds:
 DO_CUDA=${DO_CUDA:-$DO_FULL}
@@ -349,7 +350,7 @@ find lib/ -name "*dll.a" -exec rm {} \;
 
 #only keep the actual loaders, not all the other crap cx_Freeze put there:
 mkdir lib/gdk-pixbuf-2.0/2.10.0/loaders.tmp
-mv lib/gdk-pixbuf-2.0/2.10.0/loaders/libpixbufloader-*.dll lib/gdk-pixbuf-2.0/2.10.0/loaders.tmp/
+mv lib/gdk-pixbuf-2.0/2.10.0/loaders/*pixbufloader*.dll lib/gdk-pixbuf-2.0/2.10.0/loaders.tmp/
 rm -fr lib/gdk-pixbuf-2.0/2.10.0/loaders
 mv lib/gdk-pixbuf-2.0/2.10.0/loaders.tmp lib/gdk-pixbuf-2.0/2.10.0/loaders
 if [ "${DO_FULL}" == "0" ]; then
@@ -495,6 +496,26 @@ rmdir xpra/*/*/* 2> /dev/null
 rmdir xpra/*/* 2> /dev/null
 rmdir xpra/* 2> /dev/null
 
+# workaround for zeroconf - just copy it wholesale
+# since I have no idea why cx_Freeze struggles with it:
+rm -fr zeroconf
+ZEROCONF_DIR=`$PYTHON -c "import zeroconf,os;print(os.path.dirname(zeroconf.__file__))"`
+cp -apr $ZEROCONF_DIR ./
+#leave ./lib
+popd > /dev/null
+#leave ./dist
+popd > /dev/null
+if [ "${DO_SBOM}" != "0" ]; then
+	if [ "${DO_FULL}" == "1" ]; then
+		./packaging/MSWindows/BUILD.py sbom --no-light
+		./packaging/MSWindows/BUILD.py export-sbom --no-light
+	else
+		./packaging/MSWindows/BUILD.py sbom
+		./packaging/MSWindows/BUILD.py export-sbom
+	fi
+fi
+pushd dist/lib > /dev/null
+
 #zip up some modules:
 if [ "${ZIP_MODULES}" == "1" ]; then
 	#these modules contain native code or data files,
@@ -508,22 +529,16 @@ if [ "${ZIP_MODULES}" == "1" ]; then
 	zip --move -ur library.zip OpenGL encodings future paramiko html \
 			pyasn1 asn1crypto async_timeout \
 			certifi OpenSSL pkcs11 keyring \
-			ifaddr pyaes browser_cookie3 service_identity\
+			ifaddr pyaes browser_cookie3 service_identity \
 			re platformdirs attr setproctitle pyvda zipp \
 			distutils comtypes email multiprocessing packaging \
 			pkg_resources pycparser idna ctypes json \
 			http enum winreg copyreg _thread _dummythread builtins importlib \
 			logging queue urllib xml xmlrpc pyasn1_modules concurrent collections > /dev/null
 fi
-# workaround for zeroconf - just copy it wholesale
-# since I have no idea why cx_Freeze struggles with it:
-rm -fr zeroconf
-ZEROCONF_DIR=`$PYTHON -c "import zeroconf,os;print(os.path.dirname(zeroconf.__file__))"`
-cp -apr $ZEROCONF_DIR ./
-
-#leave ./lib
 popd > /dev/null
 
+pushd dist > /dev/null
 rm -fr share/xml
 rm -fr share/glib-2.0/codegen share/glib-2.0/gdb share/glib-2.0/gettext
 rm -fr share/themes/Default/gtk-2.0*
@@ -558,7 +573,7 @@ fi
 
 
 echo "* Generating gdk pixbuf loaders.cache"
-gdk-pixbuf-query-loaders.exe "dist/lib/gdk-pixbuf-2.0/2.10.0/loaders/*" | sed 's+".*dist/+"+g' > dist/lib/gdk-pixbuf-2.0/2.10.0/loaders.cache
+gdk-pixbuf-query-loaders.exe dist/lib/gdk-pixbuf-2.0/2.10.0/loaders/* | sed 's+".*dist/+"+g' > dist/lib/gdk-pixbuf-2.0/2.10.0/loaders.cache
 echo "* Generating icons and theme cache"
 for itheme in `ls dist/share/icons/`; do
 	gtk-update-icon-cache.exe -t -i "dist/share/icons/${itheme}"
